@@ -86,7 +86,7 @@ namespace clx {
 		const char* src_next = src_beg;
 		
 		wchar_t* p = new wchar_t[(src.size() + 1) * sizeof(char)];
-		check_alloc(p != NULL);
+		if (p == NULL) throw std::bad_alloc();
 		
 		wchar_t* dest_beg = p;
 		wchar_t* dest_end = p + (src.size() + 1) * sizeof(char);
@@ -129,7 +129,7 @@ namespace clx {
 		const wchar_t* src_next = src_beg;
 		
 		char* p = new char[(src.size() + 1) * sizeof(wchar_t)];
-		check_alloc(p != NULL);
+		if (p == NULL) throw std::bad_alloc();
 		
 		char* dest_beg = p;
 		char* dest_end = p + (src.size() + 1) * sizeof(wchar_t);
